==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/WebAppHostNameBindingSlotArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin

import com.pulumi.azurenative.web.WebAppHostNameBindingSlotArgs.builder
import com.pulumi.azurenative.web.kotlin.enums.AzureResourceType
import com.pulumi.azurenative.web.kotlin.enums.CustomHostNameDnsRecordType
import com.pulumi.azurenative.web.kotlin.enums.HostNameType
import com.pulumi.azurenative.web.kotlin.enums.SslState
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * A hostname binding object.
 * Azure REST API version: 2022-09-01. Prior API version in Azure Native 1.x: 2020-12-01.
 * Other available API versions: 2020-10-01, 2023-01-01.
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:web:WebAppHostNameBindingSlot myresource1 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Web/sites/{name}/slots/{slot}/hostNameBindings/{hostName}
 * ```
 * @property azureResourceName Azure resource name.
 * @property azureResourceType Azure resource type.
 * @property customHostNameDnsRecordType Custom DNS record type.
 * @property domainId Fully qualified ARM domain resource URI.
 * @property hostName Hostname in the hostname binding.
 * @property hostNameType Hostname type.
 * @property kind Kind of resource.
 * @property name Name of the app.
 * @property resourceGroupName Name of the resource group to which the resource belongs.
 * @property siteName App Service app name.
 * @property slot Name of the deployment slot. If a slot is not specified, the API will create a binding for the production slot.
 * @property sslState SSL type
 * @property thumbprint SSL certificate thumbprint
 */
public data class WebAppHostNameBindingSlotArgs(
    public val azureResourceName: Output<String>? = null,
    public val azureResourceType: Output<AzureResourceType>? = null,
    public val customHostNameDnsRecordType: Output<CustomHostNameDnsRecordType>? = null,
    public val domainId: Output<String>? = null,
    public val hostName: Output<String>? = null,
    public val hostNameType: Output<HostNameType>? = null,
    public val kind: Output<String>? = null,
    public val name: Output<String>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val siteName: Output<String>? = null,
    public val slot: Output<String>? = null,
    public val sslState: Output<SslState>? = null,
    public val thumbprint: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.web.WebAppHostNameBindingSlotArgs> {
    override fun toJava(): com.pulumi.azurenative.web.WebAppHostNameBindingSlotArgs =
        com.pulumi.azurenative.web.WebAppHostNameBindingSlotArgs.builder()
            .azureResourceName(azureResourceName?.applyValue({ args0 -> args0 }))
            .azureResourceType(azureResourceType?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .customHostNameDnsRecordType(
                customHostNameDnsRecordType?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .domainId(domainId?.applyValue({ args0 -> args0 }))
            .hostName(hostName?.applyValue({ args0 -> args0 }))
            .hostNameType(hostNameType?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .kind(kind?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .siteName(siteName?.applyValue({ args0 -> args0 }))
            .slot(slot?.applyValue({ args0 -> args0 }))
            .sslState(sslState?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .thumbprint(thumbprint?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WebAppHostNameBindingSlotArgs].
 */
@PulumiTagMarker
public class WebAppHostNameBindingSlotArgsBuilder internal constructor() {
    private var azureResourceName: Output<String>? = null

    private var azureResourceType: Output<AzureResourceType>? = null

    private var customHostNameDnsRecordType: Output<CustomHostNameDnsRecordType>? = null

    private var domainId: Output<String>? = null

    private var hostName: Output<String>? = null

    private var hostNameType: Output<HostNameType>? = null

    private var kind: Output<String>? = null

    private var name: Output<String>? = null

    private var resourceGroupName: Output<String>? = null

    private var siteName: Output<String>? = null

    private var slot: Output<String>? = null

    private var sslState: Output<SslState>? = null

    private var thumbprint: Output<String>? = null

    /**
     * @param value Azure resource name.
     */
    @JvmName("nmfcxonulmmbhdyx")
    public suspend fun azureResourceName(`value`: Output<String>) {
        this.azureResourceName = value
    }

    /**
     * @param value Azure resource type.
     */
    @JvmName("npqynrfancdhfisa")
    public suspend fun azureResourceType(`value`: Output<AzureResourceType>) {
        this.azureResourceType = value
    }

    /**
     * @param value Custom DNS record type.
     */
    @JvmName("wctehibiixyddxud")
    public suspend fun customHostNameDnsRecordType(`value`: Output<CustomHostNameDnsRecordType>) {
        this.customHostNameDnsRecordType = value
    }

    /**
     * @param value Fully qualified ARM domain resource URI.
     */
    @JvmName("nxgfamnyrslnamde")
    public suspend fun domainId(`value`: Output<String>) {
        this.domainId = value
    }

    /**
     * @param value Hostname in the hostname binding.
     */
    @JvmName("gxihgguxnaxyynwr")
    public suspend fun hostName(`value`: Output<String>) {
        this.hostName = value
    }

    /**
     * @param value Hostname type.
     */
    @JvmName("sffikvywkweqwwtd")
    public suspend fun hostNameType(`value`: Output<HostNameType>) {
        this.hostNameType = value
    }

    /**
     * @param value Kind of resource.
     */
    @JvmName("alcatnqvbcqsmohq")
    public suspend fun kind(`value`: Output<String>) {
        this.kind = value
    }

    /**
     * @param value Name of the app.
     */
    @JvmName("hiyvtwefwhsrsinn")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Name of the resource group to which the resource belongs.
     */
    @JvmName("vebrtyjqsjhrhuog")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value App Service app name.
     */
    @JvmName("sipvxygibcacvkbf")
    public suspend fun siteName(`value`: Output<String>) {
        this.siteName = value
    }

    /**
     * @param value Name of the deployment slot. If a slot is not specified, the API will create a binding for the production slot.
     */
    @JvmName("vxtrhcgqpvkqrfru")
    public suspend fun slot(`value`: Output<String>) {
        this.slot = value
    }

    /**
     * @param value SSL type
     */
    @JvmName("nhmwidttxtsfjvaq")
    public suspend fun sslState(`value`: Output<SslState>) {
        this.sslState = value
    }

    /**
     * @param value SSL certificate thumbprint
     */
    @JvmName("mgfhijuixmycjcma")
    public suspend fun thumbprint(`value`: Output<String>) {
        this.thumbprint = value
    }

    /**
     * @param value Azure resource name.
     */
    @JvmName("txciuqykqixnlcua")
    public suspend fun azureResourceName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.azureResourceName = mapped
    }

    /**
     * @param value Azure resource type.
     */
    @JvmName("ayhxjgjmtouxswjv")
    public suspend fun azureResourceType(`value`: AzureResourceType?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.azureResourceType = mapped
    }

    /**
     * @param value Custom DNS record type.
     */
    @JvmName("wguksnkyjwjixglp")
    public suspend fun customHostNameDnsRecordType(`value`: CustomHostNameDnsRecordType?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.customHostNameDnsRecordType = mapped
    }

    /**
     * @param value Fully qualified ARM domain resource URI.
     */
    @JvmName("hhyetkpnswbfuwhg")
    public suspend fun domainId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.domainId = mapped
    }

    /**
     * @param value Hostname in the hostname binding.
     */
    @JvmName("miekduuiwhkkuyht")
    public suspend fun hostName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.hostName = mapped
    }

    /**
     * @param value Hostname type.
     */
    @JvmName("nytaucbljuawxfqm")
    public suspend fun hostNameType(`value`: HostNameType?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.hostNameType = mapped
    }

    /**
     * @param value Kind of resource.
     */
    @JvmName("bkvkgalnnarpbddt")
    public suspend fun kind(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.kind = mapped
    }

    /**
     * @param value Name of the app.
     */
    @JvmName("uocvlhpqimkbntla")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Name of the resource group to which the resource belongs.
     */
    @JvmName("ukqtamahljyoddqo")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value App Service app name.
     */
    @JvmName("pxggbbhihkkxhqwn")
    public suspend fun siteName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.siteName = mapped
    }

    /**
     * @param value Name of the deployment slot. If a slot is not specified, the API will create a binding for the production slot.
     */
    @JvmName("qwenniimyhujtiih")
    public suspend fun slot(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.slot = mapped
    }

    /**
     * @param value SSL type
     */
    @JvmName("yoqryibvtibsjnjp")
    public suspend fun sslState(`value`: SslState?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sslState = mapped
    }

    /**
     * @param value SSL certificate thumbprint
     */
    @JvmName("olbrpqgdqtojhltr")
    public suspend fun thumbprint(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.thumbprint = mapped
    }

    internal fun build(): WebAppHostNameBindingSlotArgs = WebAppHostNameBindingSlotArgs(
        azureResourceName = azureResourceName,
        azureResourceType = azureResourceType,
        customHostNameDnsRecordType = customHostNameDnsRecordType,
        domainId = domainId,
        hostName = hostName,
        hostNameType = hostNameType,
        kind = kind,
        name = name,
        resourceGroupName = resourceGroupName,
        siteName = siteName,
        slot = slot,
        sslState = sslState,
        thumbprint = thumbprint,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/WebAppHostNameBindingSlotArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin

import com.pulumi.azurenative.web.WebAppHostNameBindingSlotArgs.builder
import com.pulumi.azurenative.web.kotlin.enums.AzureResourceType
import com.pulumi.azurenative.web.kotlin.enums.CustomHostNameDnsRecordType
import com.pulumi.azurenative.web.kotlin.enums.HostNameType
import com.pulumi.azurenative.web.kotlin.enums.SslState
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * A hostname binding object.
 * Azure REST API version: 2022-09-01. Prior API version in Azure Native 1.x: 2020-12-01.
 * Other available API versions: 2020-10-01, 2023-01-01.
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:web:WebAppHostNameBindingSlot myresource1 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Web/sites/{name}/slots/{slot}/hostNameBindings/{hostName}
 * ```
 * @property azureResourceName Azure resource name.
 * @property azureResourceType Azure resource type.
 * @property customHostNameDnsRecordType Custom DNS record type.
 * @property domainId Fully qualified ARM domain resource URI.
 * @property hostName Hostname in the hostname binding.
 * @property hostNameType Hostname type.
 * @property kind Kind of resource.
 * @property name Name of the app.
 * @property resourceGroupName Name of the resource group to which the resource belongs.
 * @property siteName App Service app name.
 * @property slot Name of the deployment slot. If a slot is not specified, the API will create a binding for the production slot.
 * @property sslState SSL type
 * @property thumbprint SSL certificate thumbprint
 */
public data class WebAppHostNameBindingSlotArgs(
    public val azureResourceName: Output<String>? = null,
    public val azureResourceType: Output<AzureResourceType>? = null,
    public val customHostNameDnsRecordType: Output<CustomHostNameDnsRecordType>? = null,
    public val domainId: Output<String>? = null,
    public val hostName: Output<String>? = null,
    public val hostNameType: Output<HostNameType>? = null,
    public val kind: Output<String>? = null,
    public val name: Output<String>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val siteName: Output<String>? = null,
    public val slot: Output<String>? = null,
    public val sslState: Output<SslState>? = null,
    public val thumbprint: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.web.WebAppHostNameBindingSlotArgs> {
    override fun toJava(): com.pulumi.azurenative.web.WebAppHostNameBindingSlotArgs =
        com.pulumi.azurenative.web.WebAppHostNameBindingSlotArgs.builder()
            .azureResourceName(azureResourceName?.applyValue({ args0 -> args0 }))
            .azureResourceType(azureResourceType?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .customHostNameDnsRecordType(
                customHostNameDnsRecordType?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .domainId(domainId?.applyValue({ args0 -> args0 }))
            .hostName(hostName?.applyValue({ args0 -> args0 }))
            .hostNameType(hostNameType?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .kind(kind?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .siteName(siteName?.applyValue({ args0 -> args0 }))
            .slot(slot?.applyValue({ args0 -> args0 }))
            .sslState(sslState?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .thumbprint(thumbprint?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WebAppHostNameBindingSlotArgs].
 */
@PulumiTagMarker
public class WebAppHostNameBindingSlotArgsBuilder internal constructor() {
    private var azureResourceName: Output<String>? = null

    private var azureResourceType: Output<AzureResourceType>? = null

    private var customHostNameDnsRecordType: Output<CustomHostNameDnsRecordType>? = null

    private var domainId: Output<String>? = null

    private var hostName: Output<String>? = null

    private var hostNameType: Output<HostNameType>? = null

    private var kind: Output<String>? = null

    private var name: Output<String>? = null

    private var resourceGroupName: Output<String>? = null

    private var siteName: Output<String>? = null

    private var slot: Output<String>? = null

    private var sslState: Output<SslState>? = null

    private var thumbprint: Output<String>? = null

    /**
     * @param value Azure resource name.
     */
    @JvmName("wothfihsigavhumq")
    public suspend fun azureResourceName(`value`: Output<String>) {
        this.azureResourceName = value
    }

    /**
     * @param value Azure resource type.
     */
    @JvmName("ykdfldunwplxuwmy")
    public suspend fun azureResourceType(`value`: Output<AzureResourceType>) {
        this.azureResourceType = value
    }

    /**
     * @param value Custom DNS record type.
     */
    @JvmName("alyntbcalgjqkdsm")
    public suspend fun customHostNameDnsRecordType(`value`: Output<CustomHostNameDnsRecordType>) {
        this.customHostNameDnsRecordType = value
    }

    /**
     * @param value Fully qualified ARM domain resource URI.
     */
    @JvmName("cmkrbhbqpmlnnhgt")
    public suspend fun domainId(`value`: Output<String>) {
        this.domainId = value
    }

    /**
     * @param value Hostname in the hostname binding.
     */
    @JvmName("djssxaehjpyrkptp")
    public suspend fun hostName(`value`: Output<String>) {
        this.hostName = value
    }

    /**
     * @param value Hostname type.
     */
    @JvmName("mqtlbpftlyffnaxc")
    public suspend fun hostNameType(`value`: Output<HostNameType>) {
        this.hostNameType = value
    }

    /**
     * @param value Kind of resource.
     */
    @JvmName("phxapconycautqok")
    public suspend fun kind(`value`: Output<String>) {
        this.kind = value
    }

    /**
     * @param value Name of the app.
     */
    @JvmName("nyghjxjaykkgyysb")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Name of the resource group to which the resource belongs.
     */
    @JvmName("vrejtvwuoxngfsde")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value App Service app name.
     */
    @JvmName("ehniwywnqjuwomdr")
    public suspend fun siteName(`value`: Output<String>) {
        this.siteName = value
    }

    /**
     * @param value Name of the deployment slot. If a slot is not specified, the API will create a binding for the production slot.
     */
    @JvmName("pytccysxleqvenrk")
    public suspend fun slot(`value`: Output<String>) {
        this.slot = value
    }

    /**
     * @param value SSL type
     */
    @JvmName("cbraggjundivaijp")
    public suspend fun sslState(`value`: Output<SslState>) {
        this.sslState = value
    }

    /**
     * @param value SSL certificate thumbprint
     */
    @JvmName("bbrnyuuusbhgxfxx")
    public suspend fun thumbprint(`value`: Output<String>) {
        this.thumbprint = value
    }

    /**
     * @param value Azure resource name.
     */
    @JvmName("btskxpxlhdtvaywp")
    public suspend fun azureResourceName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.azureResourceName = mapped
    }

    /**
     * @param value Azure resource type.
     */
    @JvmName("pkjspvihshospvbk")
    public suspend fun azureResourceType(`value`: AzureResourceType?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.azureResourceType = mapped
    }

    /**
     * @param value Custom DNS record type.
     */
    @JvmName("dysrlywwmivmgikj")
    public suspend fun customHostNameDnsRecordType(`value`: CustomHostNameDnsRecordType?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.customHostNameDnsRecordType = mapped
    }

    /**
     * @param value Fully qualified ARM domain resource URI.
     */
    @JvmName("cucynbtowqdglxln")
    public suspend fun domainId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.domainId = mapped
    }

    /**
     * @param value Hostname in the hostname binding.
     */
    @JvmName("awcrmaavieeykesy")
    public suspend fun hostName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.hostName = mapped
    }

    /**
     * @param value Hostname type.
     */
    @JvmName("ydggxkeuyuehasss")
    public suspend fun hostNameType(`value`: HostNameType?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.hostNameType = mapped
    }

    /**
     * @param value Kind of resource.
     */
    @JvmName("gyxhjevegaaynxlm")
    public suspend fun kind(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.kind = mapped
    }

    /**
     * @param value Name of the app.
     */
    @JvmName("wkuxcoiuywpbrvnu")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Name of the resource group to which the resource belongs.
     */
    @JvmName("ioisyttsjkkrqfaa")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value App Service app name.
     */
    @JvmName("dtkawsepvmutyrks")
    public suspend fun siteName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.siteName = mapped
    }

    /**
     * @param value Name of the deployment slot. If a slot is not specified, the API will create a binding for the production slot.
     */
    @JvmName("xlkutdsgkoapafks")
    public suspend fun slot(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.slot = mapped
    }

    /**
     * @param value SSL type
     */
    @JvmName("jegjvkqoeehidbmg")
    public suspend fun sslState(`value`: SslState?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sslState = mapped
    }

    /**
     * @param value SSL certificate thumbprint
     */
    @JvmName("ncnybdluvqjehqqv")
    public suspend fun thumbprint(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.thumbprint = mapped
    }

    internal fun build(): WebAppHostNameBindingSlotArgs = WebAppHostNameBindingSlotArgs(
        azureResourceName = azureResourceName,
        azureResourceType = azureResourceType,
        customHostNameDnsRecordType = customHostNameDnsRecordType,
        domainId = domainId,
        hostName = hostName,
        hostNameType = hostNameType,
        kind = kind,
        name = name,
        resourceGroupName = resourceGroupName,
        siteName = siteName,
        slot = slot,
        sslState = sslState,
        thumbprint = thumbprint,
    )
}
